@@ -3,7 +3,8 @@
 use Geo::IP;
 
 # here we are using GeoIP ISP
-my $gi = Geo::IP->open("/usr/local/share/GeoIP/GeoIPISP.dat", GEOIP_STANDARD);
+my $gi
+    = Geo::IP->open( "/usr/local/share/GeoIP/GeoIPISP.dat", GEOIP_STANDARD );
 
 # uncomment for GeoIP Organization
 #my $gi = Geo::IP->open("/usr/local/share/GeoIP/GeoIPOrg.dat", GEOIP_STANDARD);
@@ -12,10 +13,10 @@ my $gi = Geo::IP->open("/usr/local/share/GeoIP/GeoIPISP.dat", GEOIP_STANDARD);
 #my $gi = Geo::IP->open("/usr/local/share/GeoIP/GeoIPDomain.dat", GEOIP_STANDARD);
 
 while (<DATA>) {
-  chomp;
-  my ($org) = $gi->org_by_name($_);
-  my $netmask = $gi->last_netmask;
-  print join("\t",$_,$org, $netmask) . "\n";
+    chomp;
+    my ($org) = $gi->org_by_name($_);
+    my $netmask = $gi->last_netmask;
+    print join( "\t", $_, $org, $netmask ) . "\n";
 }
 
 __DATA__
